==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/ro.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Fișierul a fost încărcat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Fișierul încărcat depășește directiva upload_max_filesize din php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fișierul încărcat depășește directiva MAX_FILE_SIZE specificată în formularul HTML",
    "The file was only partially uploaded" : "Fișierul a fost încărcat doar parțial",
    "No file was uploaded" : "Nu a fost încărcat niciun fișier",
    "Missing a temporary folder" : "Lipsește un dosar temporar",
    "Could not write file to disk" : "Nu s-a putut scrie fișierul pe disc",
    "A PHP extension stopped the file upload" : "O extensie PHP a oprit încărcarea fișierelor",
    "No file uploaded or file size exceeds maximum of %s" : "Niciun fișier pentru încărcare sau s-a depășit maximul de %s",
    "File not found" : "Fișierul nu a fost găsit",
    "Text" : "Text",
    "Translate" : "Tradu",
    "Reload" : "Reîncarcă",
    "Guest" : "Invitat",
    "Remove link" : "Șterge link-ul",
    "guest" : "invitat",
    "Offline" : "Offline",
    "Saving …" : "Se salvează",
    "Saved" : "Salvat",
    "Unsaved changes" : "Modificări nesalvate",
    "Keyboard shortcuts" : "Scurtături din tastatură",
    "Quoted text" : "Text citat",
    "Link" : "Legătură",
    "Undo" : "Anulează ultima acțiune",
    "Redo" : "Repetă",
    "Cannot copy, please copy the link manually" : "Nu s-a putut copia, vă rugăm să copiați link-ul manual",
    "Edit link" : "Editare link",
    "Cancel" : "Anulare",
    "URL" : "URL",
    "Formatting help" : "Ajutor pentru formatare",
    "to" : "către",
    "Replace" : "Înlocuiește",
    "Upload" : "Încărcare",
    "Edit" : "Editează",
    "Source code" : "Cod sursă",
    "Done" : "Realizat",
    "Lists" : "Liste",
    "Details" : "Detalii",
    "Formatting" : "Formatare",
    "Select file or folder to link to" : "Selectați fișierul sau folderul țintă a link-ului",
    "Add folder description" : "Adăugați descrierea directorului",
    "Use current version" : "Folosește versiunea curentă",
    "Use the saved version" : "Folosește versiuna salvată",
    "Info" : "Info",
    "Success" : "Succes",
    "Warning" : "Atenție"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/ro.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Fișierul a fost încărcat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Fișierul încărcat depășește directiva upload_max_filesize din php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fișierul încărcat depășește directiva MAX_FILE_SIZE specificată în formularul HTML",
    "The file was only partially uploaded" : "Fișierul a fost încărcat doar parțial",
    "No file was uploaded" : "Nu a fost încărcat niciun fișier",
    "Missing a temporary folder" : "Lipsește un dosar temporar",
    "Could not write file to disk" : "Nu s-a putut scrie fișierul pe disc",
    "A PHP extension stopped the file upload" : "O extensie PHP a oprit încărcarea fișierelor",
    "No file uploaded or file size exceeds maximum of %s" : "Niciun fișier pentru încărcare sau s-a depășit maximul de %s",
    "File not found" : "Fișierul nu a fost găsit",
    "Text" : "Text",
    "Reload" : "Reîncarcă",
    "Enter your name" : "Introduceți numele",
    "Guest" : "Invitat",
    "you" : "tu",
    "edit" : "editare",
    "Copy link" : "Copiază link",
    "Remove link" : "Șterge link-ul",
    "guest" : "invitat",
    "Offline" : "Offline",
    "Saving …" : "Se salvează",
    "Saved" : "Salvat",
    "Unsaved changes" : "Modificări nesalvate",
    "Keyboard shortcuts" : "Scurtături din tastatură",
    "Quoted text" : "Text citat",
    "Link" : "Legătură",
    "Undo" : "Anulează ultima acțiune",
    "Redo" : "Repetă",
    "Edit link" : "Editare link",
    "Cancel" : "Anulare",
    "URL" : "URL",
    "Save" : "Salvează",
    "Formatting help" : "Ajutor pentru formatare",
    "Translate" : "Tradu",
    "to" : "către",
    "Replace" : "Înlocuiește",
    "Edit" : "Editează",
    "Upload" : "Încărcare",
    "Source code" : "Cod sursă",
    "Done" : "Realizat",
    "Lists" : "Liste",
    "Details" : "Detalii",
    "Formatting" : "Formatare",
    "Select file or folder to link to" : "Selectați fișierul sau folderul țintă a link-ului",
    "Choose" : "Alege",
    "Choose {file}" : "Selectați {file}",
    "Add folder description" : "Adăugați descrierea directorului",
    "Cannot copy, please copy the link manually" : "Nu s-a putut copia, vă rugăm să copiați link-ul manual"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
